pub async fn start_tcp_client(
config: TCPClientConfig,
tcp_receiver: Receiver<BytesMut>,
rabbitmq_sender: Sender<Reply>,
) -> Result<(), String>Expand description
Starts a TCP client that connects to the specified host and port, reads incoming messages, and processes them using the parse_reply function.
Arguments
config- Configuration options for the TCP client.tcp_receiver- An async channel receiver for sending messages to the TCP server.rabbitmq_sender- An async channel sender for propagating parsed messages to RabbitMQ.